/*
 *	HeNCE Tool
 *
 *	xcomn.h - Global includes needed for X.
 *
 *	Jun 1991  Robert Manchek  manchek@CS.UTK.EDU.
 *
 *	Revision Log
 *
$Log: xcomn.h,v $
 * Revision 1.1  1992/04/08  05:50:52  moore
 * initial RCS version
 *
 *
 */

#define	COLBGND			0	/* drawing color - background */
#define	COLFGND			1
#define	COLEXECUTING	2
#define	COLEXIT			3
#define	COLNOTREADY		4
#define	COLSTARTED		5
#define	COLCOMPLETED	6
#define	COLWARNING		7
#define	COLERROR		8

Widget cre_cmd_but();
Widget cre_tog_but();

Display *xDisp;				/* x display */
Widget infoBox;				/* info in main */
Widget mainCmd;				/* command in main */
Widget mainForm;			/* main widget layout level */
Widget topLevel;			/* main widget */
Window xRootW;				/* x screen root window */
XtAppContext context;
int xScrn;					/* x screen */
int xDispWd, xDispHt;		/* display size */
u_long bp, wp;				/* display black, white pixel */
u_long mycolor[15];			/* generic color values */

